==> apache-fory-0.12.3-src.tar.gz: apache-fory-0.12.3-src/javascript/test/set.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import Fory, { TypeInfo, InternalSerializerType, Type } from '../packages/fory/index';
import { describe, expect, test } from '@jest/globals';

describe('set', () => {
    test('should set work', () => {
        
        const fory = new Fory({ refTracking: true });    
        const input = fory.serialize(new Set(["foo1", "bar1", "cc2"]));
        const result = fory.deserialize(
            input
        );
        expect(result).toEqual(new Set(["foo1", "bar1", "cc2"]))
    });
    test('should set in object work', () => {
        const typeinfo = Type.struct({
            typeName: "example.foo"
        }, {
            a: Type.set(Type.string())
        });
        
        const fory = new Fory({ refTracking: true });    
        const { serialize, deserialize } = fory.registerSerializer(typeinfo);
        const input = serialize({ a: new Set(["foo1", "bar2"]) });
        const result = deserialize(
            input
        );
        expect(result).toEqual({ a: new Set(["foo1", "bar2"]) })
    });
});

==> apache-fory-0.15.0-src.tar.gz: apache-fory-0.15.0-src/javascript/test/set.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import Fory, { Type } from '../packages/fory/index';
import { describe, expect, test } from '@jest/globals';

describe('set', () => {
    test('should set work', () => {
        
        const fory = new Fory({ refTracking: true });    
        const input = fory.serialize(new Set(["foo1", "bar1", "cc2"]));
        const result = fory.deserialize(
            input
        );
        expect(result).toEqual(new Set(["foo1", "bar1", "cc2"]))
    });
    test('should set in object work', () => {
        const typeinfo = Type.struct({
            typeName: "example.foo"
        }, {
            a: Type.set(Type.string())
        });
        
        const fory = new Fory({ refTracking: true });    
        const { serialize, deserialize } = fory.registerSerializer(typeinfo);
        const input = serialize({ a: new Set(["foo1", "bar2"]) });
        const result = deserialize(
            input
        );
        expect(result).toEqual({ a: new Set(["foo1", "bar2"]) })
    });
});
